pub enum ActionAccessModelOps {
Insert,
Get,
Query,
Search,
Update,
Delete,
}Expand description
Model operations that an action is allowed to make.
Variants
Insert
Can create an item for this model.
Get
Can get an item for this model by UUID or Index.
Query
Can query an item for this model by queryable field.
Search
Can search an item for this model by searchable field.
Update
Can update an item for this model.
Delete
Can delete an item for this model.