pub enum IntegrationProtocol {
Http {
method: String,
headers: Vec<(String, String)>,
send_encoding: IntegrationProtocolHttpEncoding,
recv_encoding: IntegrationProtocolHttpEncoding,
},
}Expand description
The protocol for the integration.
Variants
Http
For integrating an external HTTP API.
Fields

send_encoding: IntegrationProtocolHttpEncodinghow to encode the value passed from the action

recv_encoding: IntegrationProtocolHttpEncodinghow to decode the value passed back to the action