pub enum MiddlewareValidationRule {
Any(Vec<Box<MiddlewareValidationRule>>),
All(Vec<Box<MiddlewareValidationRule>>),
Not(Box<MiddlewareValidationRule>),
StatusCode(u16),
}Variants
Any(Vec<Box<MiddlewareValidationRule>>)
if any of the rules included pass it is valid.
All(Vec<Box<MiddlewareValidationRule>>)
only if all the rules pass is it valid.
Not(Box<MiddlewareValidationRule>)
if the rule is not true then it is valid.
StatusCode(u16)
status code that will allow the request to proceed.