PasswordProtocol

Enum PasswordProtocol 

pub enum PasswordProtocol {
    Opaque,
}
Configuration for password protocol.

Variants



Opaque

When WASM is enabled, this will run the client portions browser-side. When JavaScript-only, passwords will be hashed and then sent to the server where the client portion will be done on behalf of the user. In noscript mode, the password is sent only protected by TLS, hashed and then the client operations are done server side.

If a user later decides to enable JavaScript or WASM, they’ll be able to opt in to the no-plain-password-sent modes without interruption.