pub enum SecretSource {
Env,
Stored,
}Expand description
Where Ordinary will look for the secret.
Variants
Env
Name of the host provided environment variable/secret.
Env secrets are available to every tenant for a given
API server (when running in “multi” mode).
This is useful in scenarios where a provider running the API server would like to expose convenient integrations with 3rd parties, for which it only wants to maintain a single set of credentials.
Env secrets are also useful when you’re running a standalone
application and do not need a more complicated secrets management
paradigm.
Stored
Name of a stored secret.
Stored secrets are application scoped, and can be set
through an API server on which the application runs.
Stored secrets live in their own database and are only
accessible to components with permissions.