pub struct ActionConfig {Show 16 fields
pub ffi: ActionFfi,
pub idx: u8,
pub name: String,
pub lang: ActionLang,
pub dir_path: Option<String>,
pub protected: Option<Check>,
pub transactional: Option<bool>,
pub access: Vec<ActionAccessPermission>,
pub accepts: Kind,
pub returns: Kind,
pub triggered_by: Vec<ActionTrigger>,
pub timeout: Option<u16>,
pub cors: Option<HttpCors>,
pub wasm_opt: Option<WasmOpt>,
pub privileged: Option<bool>,
pub variables: Option<Vec<String>>,
}Expand description
Configuration parameters for Ordinary Actions.
Fields
ffi: ActionFfiForeign function interface config
idx: u8Unique index value for action.
name: StringAction name. Must be unique.
lang: ActionLangThe source language the action is written in.
dir_path: Option<String>Relative path to the source directory for the action.
protected: Option<Check>What to check the token fields against. If blank action is public.
transactional: Option<bool>whether the storage interactions are executed under a single transaction.
access: Vec<ActionAccessPermission>Which Ordinary Application resources the action has access to.
accepts: KindInput definition for the action.
returns: KindOutput definition for the action.
triggered_by: Vec<ActionTrigger>How this action is called (i.e. side effect from DB/Auth, http API call, browser form submission, etc.)
timeout: Option<u16>Max duration for the action.
Unit: seconds
cors: Option<HttpCors>wasm_opt: Option<WasmOpt>privileged: Option<bool>Whether the action should have bindings for API server interaction.
Can only be set on applications which have been explicitly allow-listed by the API server administrator via their domain.
variables: Option<Vec<String>>List of build time environment variables.
format in template: {{ YOUR_VAR }}