pub struct CacheLimits {
pub max_size_range: (u64, u64),
pub max_count_range: (usize, usize),
}Fields
max_size_range: (u64, u64)max_count_range: (usize, usize)Trait Implementations
Sourceimpl Clone for CacheLimits
impl Clone for CacheLimits
Sourcefn clone(&self) -> CacheLimits
fn clone(&self) -> CacheLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CacheLimits
Available on crate feature utoipa only.
impl ComposeSchema for CacheLimits
Available on crate feature
utoipa only.Sourceimpl Debug for CacheLimits
impl Debug for CacheLimits
Sourceimpl Default for CacheLimits
impl Default for CacheLimits
Sourceimpl<'de> Deserialize<'de> for CacheLimits
impl<'de> Deserialize<'de> for CacheLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CacheLimits
Available on crate feature docs only.
impl JsonSchema for CacheLimits
Available on crate feature
docs only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CacheLimits
impl Serialize for CacheLimits