pub struct ContentUpdateConfig {
pub lifecycle: Option<LifecycleBeforeAfterScripts>,
}Fields
lifecycle: Option<LifecycleBeforeAfterScripts>Trait Implementations
Sourceimpl Clone for ContentUpdateConfig
impl Clone for ContentUpdateConfig
Sourcefn clone(&self) -> ContentUpdateConfig
fn clone(&self) -> ContentUpdateConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContentUpdateConfig
impl ComposeSchema for ContentUpdateConfig
Sourceimpl Debug for ContentUpdateConfig
impl Debug for ContentUpdateConfig
Sourceimpl<'de> Deserialize<'de> for ContentUpdateConfig
impl<'de> Deserialize<'de> for ContentUpdateConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentUpdateConfig
impl JsonSchema for ContentUpdateConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ContentUpdateConfig
impl Serialize for ContentUpdateConfig