pub struct DatabaseModelConfig {
pub idx: u8,
pub name: String,
pub fields: Vec<Field>,
pub uuid: Option<UuidVersion>,
}Expand description
Defines a model in the Ordinary Database.
Fields
idx: u8Index of the model. Used for its kind for storage keys. There can be no gaps in index values.
Note: the first (0) index is always skipped as it is reserved for the item UUID.
name: StringName of the model.
fields: Vec<Field>Fields on the model.
uuid: Option<UuidVersion>Every model is generated with a UUID key. If this value is blank, it will default to V4. If you’d like records to be ordered by time, V7 is recommended.