pub struct FunctionFfi {
pub version: FunctionFfiVersion,
pub serialization: FunctionFfiSerialization,
}Fields
version: FunctionFfiVersionserialization: FunctionFfiSerializationTrait Implementations
Sourceimpl Clone for FunctionFfi
impl Clone for FunctionFfi
Sourcefn clone(&self) -> FunctionFfi
fn clone(&self) -> FunctionFfi
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for FunctionFfi
Available on crate feature utoipa only.
impl ComposeSchema for FunctionFfi
Available on crate feature
utoipa only.Sourceimpl Debug for FunctionFfi
impl Debug for FunctionFfi
Sourceimpl Default for FunctionFfi
impl Default for FunctionFfi
Sourcefn default() -> FunctionFfi
fn default() -> FunctionFfi
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FunctionFfi
impl<'de> Deserialize<'de> for FunctionFfi
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FunctionFfi
Available on crate feature docs only.
impl JsonSchema for FunctionFfi
Available on crate feature
docs only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for FunctionFfi
impl Serialize for FunctionFfi