pub struct HttpCache {
pub cache_control: Option<HttpCacheControl>,
pub expires: Option<u64>,
pub stored: Option<StoredCache>,
pub etag: Option<HttpEtag>,
}Fields
cache_control: Option<HttpCacheControl>expires: Option<u64>Corresponds to the HTTP Expires header. https://developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Expires
Unit: seconds.
stored: Option<StoredCache>etag: Option<HttpEtag>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for HttpCache
impl<'de> Deserialize<'de> for HttpCache
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HttpCache
Available on crate feature docs only.
impl JsonSchema for HttpCache
Available on crate feature
docs only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HttpCache
impl RefUnwindSafe for HttpCache
impl Send for HttpCache
impl Sync for HttpCache
impl Unpin for HttpCache
impl UnsafeUnpin for HttpCache
impl UnwindSafe for HttpCache