pub struct HttpCsp {
pub default_src: Option<String>,
pub script_src: Option<String>,
pub style_src: Option<String>,
pub font_src: Option<String>,
pub img_src: Option<String>,
pub frame_src: Option<String>,
pub include_inline_hashes: Option<bool>,
}Fields
default_src: Option<String>defaults to 'self' (default-src does not need to be included)
script_src: Option<String>defaults to unset unless inline hashes are included,
in which case the directive will start with 'self' (script-src does not need to be included).
style_src: Option<String>defaults to unset unless inline hashes are included,
in which case the directive will start with 'self' (style-src does not need to be included).
font_src: Option<String>defaults to unset.
(font-src does not need to be included).
img_src: Option<String>defaults to unset.
(img-src does not need to be included).
frame_src: Option<String>defaults to unset.
(frame-src does not need to be included).
include_inline_hashes: Option<bool>defaults to true.
Implementations