pub struct HttpRoute {
pub function: String,
pub path: String,
pub method: HttpMethod,
pub config: Option<HttpRouteConfig>,
pub middlewares: Option<Vec<String>>,
}Fields
function: StringName of the function that will handle incoming requests.
path: StringPath for the HTTP route (must start with leading “/”).
method: HttpMethodHTTP method for this route.
config: Option<HttpRouteConfig>middlewares: Option<Vec<String>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for HttpRoute
impl<'de> Deserialize<'de> for HttpRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HttpRoute
Available on crate feature docs only.
impl JsonSchema for HttpRoute
Available on crate feature
docs only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HttpRoute
impl RefUnwindSafe for HttpRoute
impl Send for HttpRoute
impl Sync for HttpRoute
impl Unpin for HttpRoute
impl UnsafeUnpin for HttpRoute
impl UnwindSafe for HttpRoute