pub struct MfaConfig {
pub totp: TotpConfig,
}Fields
totp: TotpConfigTrait Implementations
Sourceimpl<'de> Deserialize<'de> for MfaConfig
impl<'de> Deserialize<'de> for MfaConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MfaConfig
impl JsonSchema for MfaConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MfaConfig
impl RefUnwindSafe for MfaConfig
impl Send for MfaConfig
impl Sync for MfaConfig
impl Unpin for MfaConfig
impl UnsafeUnpin for MfaConfig
impl UnwindSafe for MfaConfig