pub struct ServerLoggingConfig {
pub ips: Option<bool>,
pub headers: Option<bool>,
pub credentials: Option<RedactedHashAlg>,
pub timing: Option<bool>,
pub sizes: Option<bool>,
}Fields
ips: Option<bool>headers: Option<bool>credentials: Option<RedactedHashAlg>timing: Option<bool>sizes: Option<bool>Trait Implementations
Sourceimpl Clone for ServerLoggingConfig
impl Clone for ServerLoggingConfig
Sourcefn clone(&self) -> ServerLoggingConfig
fn clone(&self) -> ServerLoggingConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServerLoggingConfig
Available on crate feature utoipa only.
impl ComposeSchema for ServerLoggingConfig
Available on crate feature
utoipa only.Sourceimpl Debug for ServerLoggingConfig
impl Debug for ServerLoggingConfig
Sourceimpl<'de> Deserialize<'de> for ServerLoggingConfig
impl<'de> Deserialize<'de> for ServerLoggingConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServerLoggingConfig
Available on crate feature docs only.
impl JsonSchema for ServerLoggingConfig
Available on crate feature
docs only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ServerLoggingConfig
impl Serialize for ServerLoggingConfig