pub struct TemplateCache {
pub stored: Option<StoredCache>,
pub http: Option<HttpCache>,
}Fields
stored: Option<StoredCache>http: Option<HttpCache>Trait Implementations
Sourceimpl Clone for TemplateCache
impl Clone for TemplateCache
Sourcefn clone(&self) -> TemplateCache
fn clone(&self) -> TemplateCache
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TemplateCache
impl ComposeSchema for TemplateCache
Sourceimpl Debug for TemplateCache
impl Debug for TemplateCache
Sourceimpl<'de> Deserialize<'de> for TemplateCache
impl<'de> Deserialize<'de> for TemplateCache
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateCache
impl JsonSchema for TemplateCache
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TemplateCache
impl Serialize for TemplateCache