pub struct TemplateRefField {
pub idx: u8,
pub name: String,
pub bind: Option<TemplateRefFieldBind>,
pub fields: Option<Vec<TemplateRefField>>,
}Expand description
Declaration for which fields from a content definition or data model to include.
Fields
idx: u8Specifies index for reference field. Index must be unique across fields for a given reference.
name: StringName of field to be included.
bind: Option<TemplateRefFieldBind>Option to bind this field’s value to a route segment, querystring parameter or token field.
IMPORTANT: this property is being deprecated.
Switch to using the TemplateRef::predicate config
field, instead.
fields: Option<Vec<TemplateRefField>>List of any nested subfields to include for this field.