pub struct LifecycleBeforeAfterScripts {
pub before: Option<Vec<Vec<String>>>,
pub after: Option<Vec<Vec<String>>>,
}Fields
before: Option<Vec<Vec<String>>>after: Option<Vec<Vec<String>>>Trait Implementations
Sourceimpl Clone for LifecycleBeforeAfterScripts
impl Clone for LifecycleBeforeAfterScripts
Sourcefn clone(&self) -> LifecycleBeforeAfterScripts
fn clone(&self) -> LifecycleBeforeAfterScripts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for LifecycleBeforeAfterScripts
impl ComposeSchema for LifecycleBeforeAfterScripts
Sourceimpl Debug for LifecycleBeforeAfterScripts
impl Debug for LifecycleBeforeAfterScripts
Sourceimpl<'de> Deserialize<'de> for LifecycleBeforeAfterScripts
impl<'de> Deserialize<'de> for LifecycleBeforeAfterScripts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LifecycleBeforeAfterScripts
impl JsonSchema for LifecycleBeforeAfterScripts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LifecycleBeforeAfterScripts
impl RefUnwindSafe for LifecycleBeforeAfterScripts
impl Send for LifecycleBeforeAfterScripts
impl Sync for LifecycleBeforeAfterScripts
impl Unpin for LifecycleBeforeAfterScripts
impl UnsafeUnpin for LifecycleBeforeAfterScripts
impl UnwindSafe for LifecycleBeforeAfterScripts